@@ -1,12 +1,20 @@
 import sys
+import time
 import types
+from inspect import getmembers, isbuiltin
 
 from je_web_runner.je_web_runner.manager.webrunner_manager import web_runner
 from je_web_runner.utils.exception.exception_tags import add_command_exception_tag
 from je_web_runner.utils.exception.exception_tags import executor_data_error, executor_list_error
 from je_web_runner.utils.exception.exceptions import WebRunnerExecuteException, WebRunnerAddCommandException
-from je_web_runner.utils.html_report.html_report_generate import generate_html
+from je_web_runner.utils.generate_report.generate_html_report import generate_html_report
+from je_web_runner.utils.generate_report.generate_html_report import generate_html
+from je_web_runner.utils.generate_report.generate_json_report import generate_json
+from je_web_runner.utils.generate_report.generate_json_report import generate_json_report
+from je_web_runner.utils.generate_report.generate_xml_report import generate_xml
+from je_web_runner.utils.generate_report.generate_xml_report import generate_xml_report
 from je_web_runner.utils.json.json_file.json_file import read_action_json
+from je_web_runner.utils.package_manager.package_manager_class import package_manager
 from je_web_runner.utils.test_object.test_object_record.test_object_record_class import test_object_record
 from je_web_runner.utils.test_record.test_record_class import test_record_instance
 
@@ -93,9 +101,21 @@ class Executor(object):
             "element_get_select": web_runner.webdriver_element.get_select,
             # init test record
             "set_record_enable": test_record_instance.set_record_enable,
-            # generate html
+            # generate report
             "generate_html": generate_html,
+            "generate_html_report": generate_html_report,
+            "generate_json": generate_json,
+            "generate_json_report": generate_json_report,
+            "generate_xml": generate_xml,
+            "generate_xml_report": generate_xml_report,
+            # execute
+            "execute_action": self.execute_action,
+            "execute_files": self.execute_files,
+            "add_package_to_executor": package_manager.add_package_to_executor,
         }
+        # get all time module builtin function and add to event dict
+        for function in getmembers(time, isbuiltin):
+            self.event_dict.update({str(function): function})
 
     def _execute_event(self, action: list):
         """
@@ -161,6 +181,7 @@ class Executor(object):
 
 
 executor = Executor()
+package_manager.executor = executor
 
 
 def add_command_to_executor(command_dict: dict):
